Package: MantelCorr
Title: Compute Mantel Cluster Correlations
Version: 1.83.0
Date: 2005-17-10
Author: Brian Steinmeyer and William Shannon
Description: Computes Mantel cluster correlations from a (p x n)
        numeric data matrix (e.g. microarray gene-expression data).
Maintainer: Brian Steinmeyer <steinmeb@ilya.wustl.edu>
Depends: R (>= 2.10)
Imports: stats
License: GPL (>= 2)
biocViews: Clustering
git_url: https://git.bioconductor.org/packages/MantelCorr
git_branch: devel
git_last_commit: 3b313ab
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:31:43 UTC; biocbuild
